import React, { Component } from "react";
import Chip from '@material-ui/core/Chip';
import Input from '@material-ui/core/Input';
import Select from '@material-ui/core/Select';
import MenuItem from '@material-ui/core/MenuItem';
import Card from "components/Card/Card.jsx";
import FloatGroup from 'react-float-button';
import { Link } from "react-router-dom";
import { timeRef,firebases } from '../config';
import {TableHeaderColumn} from 'react-bootstrap-table';
import BootstrapTable from 'react-bootstrap-table-next';
import 'react-bootstrap-table/dist/react-bootstrap-table-all.min.css';
import paginationFactory from 'react-bootstrap-table2-paginator'; 
import Paper from '@material-ui/core/Paper';
import {CSVLink} from 'react-csv';
import Button from '@material-ui/core/Button';
import PropTypes from 'prop-types';
import { withStyles } from '@material-ui/core/styles';
import AppBar from '@material-ui/core/AppBar';
import Toolbar from '@material-ui/core/Toolbar';
import Typography from '@material-ui/core/Typography';

import TextField from '@material-ui/core/TextField';
import _ from 'underscore';
import {
  Template,
  TemplatePlaceholder,
  TemplateConnector,
} from '@devexpress/dx-react-core';
import { EditingState,DataTypeProvider } from '@devexpress/dx-react-grid';
import {
  PagingState,
  IntegratedPaging,
} from '@devexpress/dx-react-grid';
import {
  Grid,
  Table,
  TableHeaderRow,
  PagingPanel,
  TableColumnResizing,
   TableEditRow,
  TableEditColumn
} from '@devexpress/dx-react-grid-material-ui';
import FileUploader from "react-firebase-file-uploader";

let context  = null;

const getRowId = row => row.key;
const firebaseModel = firebases.database().ref().child({FIREBASEMODEL});
const modelHead = {MODELHEAD};

class {CLASSNAME} extends Component {

  constructor(props){
      super();
      this.state ={
        
    modelList:[],
    username: "",
    avatar: "",
    isUploading: false,
    progress: 0,
    dateTime: null,
    avatarURL: ""};
    context = this;
  }

  componentDidMount(){

    this.getSurveys();

  }

  setDate = (dateTime) => this.setState({ dateTime })


  deleteCompany = (key) => {
    
    firebaseModel.child(key).remove();
  };


  updateCompany = (key,survey) => {
      firebaseModel.child(key).update(survey);
  };


  addNewCompany = (company) => {
    
   
    firebaseModel.push(company);
    
  };


  handleChangeUsername = event =>
    this.setState({ username: event.target.value });
  handleUploadStart = () => this.setState({ isUploading: true, progress: 0 });
  handleProgress = progress => this.setState({ progress });
  handleUploadError = error => {
    this.setState({ isUploading: false });
    console.error(error);
  };
  handleUploadSuccess = filename => {
    this.setState({ avatar: filename, progress: 100, isUploading: false });
    firebases
      .storage()
      .ref("raceAttachments")
      .child(filename)
      .getDownloadURL()
      .then(url => this.setState({ avatarURL: url }));
  };

  getSurveys(){


    firebaseModel.on('value', snap => {
      console.log(snap);
      const surveyList = [];
      console.log(snap);
      snap.forEach(survey => {
        surveyList.push({ ...survey.val(), key: survey.key });
      });

      console.log(surveyList);

      context.setState({modelList: surveyList.reverse()});


     
      this.commitChanges = this.commitChanges.bind(this);
     

    });
  }


  commitChanges({ added, changed, deleted }) {
    let  rows  = context.state.companyList;
    if (added) {
       context.addNewCompany(added[0]);
    }
    if (changed) {
     //rows = rows.map(row => (changed[row.key] ? ({ ...row, ...changed[row.key] }) : row));
     let key  = _.keys(changed)[0];
     context.updateCompany(key,changed[key]);
    
    }
    if (deleted) {
      const deletedSet = new Set(deleted);
      rows = rows.filter(row => !deletedSet.has(row.key));
      context.deleteCompany(deleted[0]);
    }
    //context.setState({ rows });
  }


  render() {
   
    return (<div>
     
     <AppBar position="sticky" color="primary">
        <Toolbar>
          <Typography variant="title" color="inherit">
            View Add or Edit States
          </Typography>
           <CSVLink data={this.state.modelList}
  filename={"states.csv"}
  className="btn-block btn btn-default export-btn"
  target="_blank">
    Export to Excel
</CSVLink>
        </Toolbar>
      </AppBar>
       <div className="container table-mi">
<Paper>
        <Grid
          rows={this.state.modelList}
          columns={modelHead}
          getRowId={getRowId}
        >
     
          <PagingState
            defaultCurrentPage={0}
            pageSize={12}
          />
          <IntegratedPaging />
         
        
          
           <EditingState
            onCommitChanges={this.commitChanges}
          />
          <Table />
          <TableHeaderRow />
            <TableEditRow />
          <TableEditColumn
            showAddCommand
            showEditCommand
            showDeleteCommand
          />
          <PagingPanel />
        </Grid>
      </Paper>
    </div>
    </div>
    );
  }
}

export default {CLASSNAME};
