#!/usr/bin/env node
let shell = require('shelljs')
let colors = require('colors')
let fs = require('fs') //fs already comes included with node.
let templates = require('./templates/basic/template.js')
let appName = process.argv[2]
let appDirectory = `${process.cwd()}/${appName}`
let adminConfigCli = require('./configuration-cli/cli');

const run = async () => {
    let success = await createReactApp()
    if(!success){
      console.log('Something went wrong while trying to create a new React app using create-react-app'.red)
      return false;
    }
    await cdIntoNewApp();
    await initializeAdminApp();
    //await installPackages();
    //await updateTemplates();
    console.log("All done".green);
  }



  const createReactApp = () => {
    return new Promise(resolve=>{
      if(appName){
        shell.exec(`create-react-app ${appName} --scripts-version ficklebeans-create-admin-panel-app`, () => {
          console.log("Created react app")
          resolve(true)
        })
      }else{
        console.log("\nNo app name was provided.".red)
        console.log("\nProvide an app name in the following format: ")
        console.log("\ncreate-ficklebeans-admin ", "app-name\n".cyan)
          resolve(false)
      }
    })
  }


  const cdIntoNewApp = () => {
    return new Promise(resolve=>{
      shell.exec(`cd ${appName}`, ()=>{resolve()})
    })
  }


  const installPackages = () => {
    return new Promise(resolve=>{
      console.log("\nInstalling redux, react-router, react-router-dom, react-redux, and redux-thunk\n".cyan)
      shell.exec(`npm install --save redux react-router react-redux redux-thunk react-router-dom`, () => {
        console.log("\nFinished installing packages\n".green)
        resolve()
      })
    })
  }


  const updateTemplates = () => {
    return new Promise(resolve=>{
      let promises = []
      Object.keys(templates).forEach((fileName, i)=>{
        promises[i] = new Promise(res=>{
          fs.writeFile(`${appDirectory}/src/${fileName}`, templates[fileName], function(err) {
              if(err) { return console.log(err) }
              res()
          })
        })
      })
      Promise.all(promises).then(()=>{resolve()})
    })
  }



  const initializeAdminApp = () =>{
return new Promise(resolve=>{

  console.log("\nDownloading Admin Panel Themes\n".cyan)
  adminConfigCli();
  console.log("\nFinished admin panel settings\n".green)
  resolve();





});



  }

  run();